package de.fhdw.gaming.ipspiel23.tictactoe.core.evaluation;

import java.util.Optional;

import de.fhdw.gaming.ipspiel23.tictactoe.core.domain.TicTacToeState;

/**
 * Interface for the evaluation strategy used to evaluate the state of a Tic-Tac-Toe game.
 * Evaluation strategies are responsible for assigning a score to a game state, 
 * indicating the desirability of that state.
 * Implementations of this interface should provide a method to evaluate the given Tic-Tac-Toe game state.
 * 
 * The evaluation result is an optional integer value, 
 * where a higher value represents a more desirable state for the current player.
 * 
 * @see TicTacToeState
 * @see java.util.Optional
 * 
 */
public interface IEvaluationStrategy {
     
    /**
     * Evaluates the given Tic-Tac-Toe game state.
     * 
     * @param state The Tic-Tac-Toe game state to be evaluated.
     * @return An optional containing the evaluation result as an integer value.
     */
     Optional<Integer> evaluateState(TicTacToeState state);
}
